/*
 * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#ifndef PREFS_DIALOG_H
#define PREFS_DIALOG_H
#include <gtk/gtk.h>
#include <panel-applet.h>

G_BEGIN_DECLS

GtkWidget *
prefs_dialog_new (PanelApplet *applet);
void
prefs_dialog_open (GtkDialog *prefs_dialog);
void
prefs_dialog_update (GtkDialog *prefs_dialog);

G_END_DECLS

#endif /* PREFS_DIALOG_H */
